<?xml version="1.0"?>

<!--
This XSL style sheet specifies how XML documents which conform to Table.dtd
should be transformed into HTML.  The generated HTML includes an HTML table
that has HTML buttons in its header.  An external JavaScript function called
"sort" is invoked when the buttons are clicked.  Each button has name that
indicates the column number in which it resides.  The "sort" function uses
this to modify the in-memory representation (DOM) of this stylesheet to
sort on the selected column.  This is achieved by modifying the "order-by"
attribute of the "xsl:apply-templates" element in the "table" rule below.
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/TR/WD-xsl">

  <xsl:template match="/">
    <xsl:apply-templates select="table"/>
  </xsl:template>

  <xsl:template match="table">
    <div>
      <xsl:attribute name="style">
        font:large; color:<xsl:value-of select="caption/@color"/>
      </xsl:attribute>
      <xsl:value-of select="caption"/>
    </div>
    
    <table border="2">
      <xsl:apply-templates select="header"/>
      
      <!-- Defaults to sorting on first column. -->
      <!-- This can be modified using DOM from JavaScript. -->
      <xsl:apply-templates id="applySort" select="row" order-by="data[0]"/>
    </table>
  </xsl:template>
  
  <xsl:template match="header">
    <tr>
      <xsl:attribute name="style">
        background:<xsl:value-of select="@backgroundColor"/>
      </xsl:attribute>

      <xsl:for-each select="column">
        <th align="left">
          <xsl:if test="@width">
            <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
          </xsl:if>
        
          <button onClick="sort(this)">
            <xsl:attribute name="name">
              <xsl:eval>childNumber(this)</xsl:eval>
            </xsl:attribute>
            <xsl:attribute name="style">
              background:<xsl:value-of select="../@buttonColor"/>
            </xsl:attribute>
            <xsl:value-of select="@label"/>
          </button>
        </th>
      </xsl:for-each>
    </tr>
  </xsl:template>
  
  <xsl:template match="row">
    <tr>
      <xsl:for-each select="data">
        <td>
          <xsl:attribute name="align"><xsl:value-of select="@align"/></xsl:attribute>
          <xsl:value-of select="."/>
        </td>
      </xsl:for-each>
    </tr>
  </xsl:template>
  
</xsl:stylesheet>